@@ -1,6 +1,6 @@
 from pandas import DataFrame as PDDataFrame
 
-from src.pandas_orm.exceptions import DataFrameModelNotSpecified
+from pandas_orm.base.exceptions import DataFrameModelNotSpecified
 
 
 class BaseDataFrame(PDDataFrame):
